pub trait DecodePrivateKey: Sized {
// Required method
fn from_pkcs8_der(bytes: &[u8]) -> Result<Self, Error>;
// Provided methods
fn from_pkcs8_pem(s: &str) -> Result<Self, Error> { ... }
fn read_pkcs8_der_file(path: impl AsRef<Path>) -> Result<Self, Error> { ... }
fn read_pkcs8_pem_file(path: impl AsRef<Path>) -> Result<Self, Error> { ... }
}Expand description
Parse a private key object from a PKCS#8 encoded document.
Required Methods
Provided Methods
Sourcefn from_pkcs8_pem(s: &str) -> Result<Self, Error>
fn from_pkcs8_pem(s: &str) -> Result<Self, Error>
Deserialize PKCS#8-encoded private key from PEM.
Keys in this format begin with the following delimiter:
-----BEGIN PRIVATE KEY-----Errors
- Returns
Error::Asn1in the event of a decoding error (PEM or DER). - Returns the same errors as
DecodePrivateKey::from_pkcs8_der.
Sourcefn read_pkcs8_der_file(path: impl AsRef<Path>) -> Result<Self, Error>
fn read_pkcs8_der_file(path: impl AsRef<Path>) -> Result<Self, Error>
Load PKCS#8 private key from an ASN.1 DER-encoded file (binary format) on the local filesystem.
Errors
- Returns the same errors as
DecodePrivateKey::from_pkcs8_der. - Returns errors in event the file cannot be read from the filesystem.
Sourcefn read_pkcs8_pem_file(path: impl AsRef<Path>) -> Result<Self, Error>
fn read_pkcs8_pem_file(path: impl AsRef<Path>) -> Result<Self, Error>
Load PKCS#8 private key from a PEM-encoded file on the local filesystem.
Errors
- Returns the same errors as
SecretDocument::read_pem_file. - Returns the same errors as
DecodePrivateKey::from_pkcs8_der. - Returns errors in event the file cannot be read from the filesystem.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.